==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/virtualmachineimages/kotlin/inputs/ImageTemplateFileCustomizerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.virtualmachineimages.kotlin.inputs

import com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Uploads files to VMs (Linux, Windows). Corresponds to Packer file provisioner
 * @property destination The absolute path to a file (with nested directory structures already created) where the file (from sourceUri) will be uploaded to in the VM
 * @property name Friendly Name to provide context on what this customization step does
 * @property sha256Checksum SHA256 checksum of the file provided in the sourceUri field above
 * @property sourceUri The URI of the file to be uploaded for customizing the VM. It can be a github link, SAS URI for Azure Storage, etc
 * @property type The type of customization tool you want to use on the Image. For example, "Shell" can be shell customizer
 * Expected value is 'File'.
 */
public data class ImageTemplateFileCustomizerArgs(
    public val destination: Output<String>? = null,
    public val name: Output<String>? = null,
    public val sha256Checksum: Output<String>? = null,
    public val sourceUri: Output<String>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs> {
    override fun toJava():
        com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs =
        com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs.builder()
            .destination(destination?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .sha256Checksum(sha256Checksum?.applyValue({ args0 -> args0 }))
            .sourceUri(sourceUri?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImageTemplateFileCustomizerArgs].
 */
@PulumiTagMarker
public class ImageTemplateFileCustomizerArgsBuilder internal constructor() {
    private var destination: Output<String>? = null

    private var name: Output<String>? = null

    private var sha256Checksum: Output<String>? = null

    private var sourceUri: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The absolute path to a file (with nested directory structures already created) where the file (from sourceUri) will be uploaded to in the VM
     */
    @JvmName("ljujrumtnrmmjuad")
    public suspend fun destination(`value`: Output<String>) {
        this.destination = value
    }

    /**
     * @param value Friendly Name to provide context on what this customization step does
     */
    @JvmName("oopwodefyunprkoc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value SHA256 checksum of the file provided in the sourceUri field above
     */
    @JvmName("bjvlhopiysqvxeda")
    public suspend fun sha256Checksum(`value`: Output<String>) {
        this.sha256Checksum = value
    }

    /**
     * @param value The URI of the file to be uploaded for customizing the VM. It can be a github link, SAS URI for Azure Storage, etc
     */
    @JvmName("cagthavwlqjjuqig")
    public suspend fun sourceUri(`value`: Output<String>) {
        this.sourceUri = value
    }

    /**
     * @param value The type of customization tool you want to use on the Image. For example, "Shell" can be shell customizer
     * Expected value is 'File'.
     */
    @JvmName("vlxnghtfxicihayx")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The absolute path to a file (with nested directory structures already created) where the file (from sourceUri) will be uploaded to in the VM
     */
    @JvmName("wfhpkfdultkoerai")
    public suspend fun destination(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destination = mapped
    }

    /**
     * @param value Friendly Name to provide context on what this customization step does
     */
    @JvmName("rwrhgqhbsxxbytle")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SHA256 checksum of the file provided in the sourceUri field above
     */
    @JvmName("epbextodllpeqldq")
    public suspend fun sha256Checksum(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sha256Checksum = mapped
    }

    /**
     * @param value The URI of the file to be uploaded for customizing the VM. It can be a github link, SAS URI for Azure Storage, etc
     */
    @JvmName("pryydsgxuwmabtdu")
    public suspend fun sourceUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceUri = mapped
    }

    /**
     * @param value The type of customization tool you want to use on the Image. For example, "Shell" can be shell customizer
     * Expected value is 'File'.
     */
    @JvmName("tfbvnqvugnrhtikr")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ImageTemplateFileCustomizerArgs = ImageTemplateFileCustomizerArgs(
        destination = destination,
        name = name,
        sha256Checksum = sha256Checksum,
        sourceUri = sourceUri,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/virtualmachineimages/kotlin/inputs/ImageTemplateFileCustomizerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.virtualmachineimages.kotlin.inputs

import com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Uploads files to VMs (Linux, Windows). Corresponds to Packer file provisioner
 * @property destination The absolute path to a file (with nested directory structures already created) where the file (from sourceUri) will be uploaded to in the VM
 * @property name Friendly Name to provide context on what this customization step does
 * @property sha256Checksum SHA256 checksum of the file provided in the sourceUri field above
 * @property sourceUri The URI of the file to be uploaded for customizing the VM. It can be a github link, SAS URI for Azure Storage, etc
 * @property type The type of customization tool you want to use on the Image. For example, "Shell" can be shell customizer
 * Expected value is 'File'.
 */
public data class ImageTemplateFileCustomizerArgs(
    public val destination: Output<String>? = null,
    public val name: Output<String>? = null,
    public val sha256Checksum: Output<String>? = null,
    public val sourceUri: Output<String>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs> {
    override fun toJava():
        com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs =
        com.pulumi.azurenative.virtualmachineimages.inputs.ImageTemplateFileCustomizerArgs.builder()
            .destination(destination?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .sha256Checksum(sha256Checksum?.applyValue({ args0 -> args0 }))
            .sourceUri(sourceUri?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImageTemplateFileCustomizerArgs].
 */
@PulumiTagMarker
public class ImageTemplateFileCustomizerArgsBuilder internal constructor() {
    private var destination: Output<String>? = null

    private var name: Output<String>? = null

    private var sha256Checksum: Output<String>? = null

    private var sourceUri: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The absolute path to a file (with nested directory structures already created) where the file (from sourceUri) will be uploaded to in the VM
     */
    @JvmName("kjcytwijrxykwlyj")
    public suspend fun destination(`value`: Output<String>) {
        this.destination = value
    }

    /**
     * @param value Friendly Name to provide context on what this customization step does
     */
    @JvmName("qsmcmnllludgwjss")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value SHA256 checksum of the file provided in the sourceUri field above
     */
    @JvmName("qrkvkmyyxdnjqrbd")
    public suspend fun sha256Checksum(`value`: Output<String>) {
        this.sha256Checksum = value
    }

    /**
     * @param value The URI of the file to be uploaded for customizing the VM. It can be a github link, SAS URI for Azure Storage, etc
     */
    @JvmName("adbsqoqdltowjoqj")
    public suspend fun sourceUri(`value`: Output<String>) {
        this.sourceUri = value
    }

    /**
     * @param value The type of customization tool you want to use on the Image. For example, "Shell" can be shell customizer
     * Expected value is 'File'.
     */
    @JvmName("kdptiagywqldpqcw")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The absolute path to a file (with nested directory structures already created) where the file (from sourceUri) will be uploaded to in the VM
     */
    @JvmName("xckynehkquowflnl")
    public suspend fun destination(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destination = mapped
    }

    /**
     * @param value Friendly Name to provide context on what this customization step does
     */
    @JvmName("snvqmkdeunbciran")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SHA256 checksum of the file provided in the sourceUri field above
     */
    @JvmName("wipfgasgqafhkqvb")
    public suspend fun sha256Checksum(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sha256Checksum = mapped
    }

    /**
     * @param value The URI of the file to be uploaded for customizing the VM. It can be a github link, SAS URI for Azure Storage, etc
     */
    @JvmName("jedvkjudcvuqoqwn")
    public suspend fun sourceUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceUri = mapped
    }

    /**
     * @param value The type of customization tool you want to use on the Image. For example, "Shell" can be shell customizer
     * Expected value is 'File'.
     */
    @JvmName("bpfgagftxavjcxgc")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ImageTemplateFileCustomizerArgs = ImageTemplateFileCustomizerArgs(
        destination = destination,
        name = name,
        sha256Checksum = sha256Checksum,
        sourceUri = sourceUri,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
